@@ -1,69 +1,85 @@
 package App::Sqitch::Command::bundle;
 
-use 5.010;
+use v5.10.1;
 use strict;
 use warnings;
 use utf8;
-use Moo;
-use App::Sqitch::Types qw(Str Dir Maybe Bool);
+use Moose;
+use MooseX::Types::Path::Class;
 use File::Path qw(make_path);
 use Path::Class;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use File::Copy ();
-use List::Util qw(first);
 use namespace::autoclean;
 
 extends 'App::Sqitch::Command';
-with 'App::Sqitch::Role::ContextCommand';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
 has from => (
     is       => 'ro',
-    isa      => Maybe[Str],
+    isa      => 'Maybe[Str]',
 );
 
 has to => (
     is       => 'ro',
-    isa      => Maybe[Str],
+    isa      => 'Maybe[Str]',
 );
 
 has dest_dir => (
     is       => 'ro',
-    isa      => Dir,
-    lazy     => 1,
+    isa      => 'Path::Class::Dir',
+    required => 1,
     default  => sub { dir 'bundle' },
 );
 
-has all => (
-    is      => 'ro',
-    isa     => Bool,
-    default => 0
+has dest_top_dir => (
+    is       => 'ro',
+    isa      => 'Path::Class::Dir',
+    required => 1,
+    default  => sub {
+        my $self = shift;
+        dir $self->dest_dir, $self->sqitch->top_dir->relative;
+    },
 );
 
-sub dest_top_dir {
-    my $self = shift;
-    dir $self->dest_dir, shift->top_dir->relative;
-}
+has dest_deploy_dir => (
+    is       => 'ro',
+    isa      => 'Path::Class::Dir',
+    required => 1,
+    lazy     => 1,
+    default  => sub {
+        my $self = shift;
+        dir $self->dest_dir, $self->sqitch->deploy_dir->relative;
+    },
+);
 
-sub dest_dirs_for {
-    my ($self, $target) = @_;
-    my $dest = $self->dest_dir;
-    return {
-        deploy          => dir($dest, $target->deploy_dir->relative),
-        revert          => dir($dest, $target->revert_dir->relative),
-        verify          => dir($dest, $target->verify_dir->relative),
-        reworked_deploy => dir($dest, $target->reworked_deploy_dir->relative),
-        reworked_revert => dir($dest, $target->reworked_revert_dir->relative),
-        reworked_verify => dir($dest, $target->reworked_verify_dir->relative),
-    };
-}
+has dest_revert_dir => (
+    is       => 'ro',
+    isa      => 'Path::Class::Dir',
+    required => 1,
+    lazy     => 1,
+    default  => sub {
+        my $self = shift;
+        dir $self->dest_dir, $self->sqitch->revert_dir->relative;
+    },
+);
+
+has dest_test_dir => (
+    is       => 'ro',
+    isa      => 'Path::Class::Dir',
+    required => 1,
+    lazy     => 1,
+    default  => sub {
+        my $self = shift;
+        dir $self->dest_dir, $self->sqitch->test_dir->relative;
+    },
+);
 
 sub options {
     return qw(
-        dest-dir|dir=s
-        all|a!
+        dest_dir|dir=s
         from=s
         to=s
     );
@@ -78,8 +94,8 @@ sub configure {
         $params{dest_dir} = dir $dir;
     }
 
-    # Make sure we get the --all, --from and --to options passed through.
-    for my $key (qw(all from to)) {
+    # Make sure we get the --from and --to options passed through.
+    for my $key (qw(from to)) {
         $params{$key} = $opt->{$key} if exists $opt->{$key};
     }
 
@@ -88,45 +104,26 @@ sub configure {
 
 sub execute {
     my $self = shift;
-    my ($targets, $changes) = $self->parse_args(
-        all  => $self->all,
-        args => \@_,
-    );
-
-    # Warn if --to or --from is specified for more thane one target.
-    if ( @{ $targets } > 1 && ($self->from || $self->to) ) {
-        $self->sqitch->warn(__(
-            "Use of --to or --from to bundle multiple targets is not recommended.\nPass them as arguments after each target argument, instead."
-        ));
-    }
-
-    # Die if --to or --from and changes are specified.
-    if ( @{ $changes } && ($self->from || $self->to) ) {
-        hurl bundle => __(
-            'Cannot specify both --from or --to and change arguments'
-        );
-    }
-
-    # Time to get started!
     $self->info(__x 'Bundling into {dir}', dir => $self->dest_dir );
     $self->bundle_config;
+    $self->bundle_plan;
+    $self->bundle_scripts;
+}
 
-    if (my @fromto = grep { $_ } $self->from, $self->to) {
-        # One set of from/to options for all targets.
-        for my $target (@{ $targets }) {
-            $self->bundle_plan($target, @fromto);
-            $self->bundle_scripts($target, @fromto);
-        }
-    } else {
-        # Separate from/to options for all targets.
-        for my $target (@{ $ targets }) {
-            my @fromto = splice @{ $changes }, 0, 2;
-            $self->bundle_plan($target, @fromto);
-            $self->bundle_scripts($target, @fromto);
-        }
-    }
+sub _mkpath {
+    my ( $self, $dir ) = @_;
+    $self->debug( '    ', __x 'Created {file}', file => $dir )
+        if make_path $dir, { error => \my $err };
 
-    return $self;
+    my $diag = shift @{ $err } or return $self;
+
+    my ( $path, $msg ) = %{ $diag };
+    hurl bundle => __x(
+        'Error creating {path}: {error}',
+        path  => $path,
+        error => $msg,
+    ) if $path;
+    hurl bundle => $msg;
 }
 
 sub _copy_if_modified {
@@ -139,7 +136,7 @@ sub _copy_if_modified {
 
     if (-e $dst) {
         # Skip the file if it is up-to-date.
-        return $self if -M $dst <= -M $src;
+        return $self if -M $dst < -M $src;
     } else {
         # Create the directory.
         $self->_mkpath( $dst->dir );
@@ -151,8 +148,7 @@ sub _copy_if_modified {
         dest   => $dst
     ));
 
-    # Stringify to work around bug in File::Copy warning on 5.10.0.
-    File::Copy::copy "$src", "$dst" or hurl bundle => __x(
+    File::Copy::copy($src, $dst) or hurl bundle => __x(
         'Cannot copy "{source}" to "{dest}": {error}',
         source => $src,
         dest   => $dst,
@@ -169,76 +165,71 @@ sub bundle_config {
 }
 
 sub bundle_plan {
-    my ($self, $target, $from, $to) = @_;
-
-    my $dir = $self->dest_top_dir($target);
-
-    if (!defined $from && !defined $to) {
+    my $self   = shift;
+    my $sqitch = $self->sqitch;
+    if (!defined $self->from && !defined $self->to) {
         $self->info(__ 'Writing plan');
-        my $file = $target->plan_file;
+        my $file = $self->sqitch->plan_file;
         return $self->_copy_if_modified(
             $file,
-            $dir->file( $file->basename ),
+            $self->dest_top_dir->file( $file->basename ),
         );
     }
 
     $self->info(__x(
         'Writing plan from {from} to {to}',
-        from => $from // '@ROOT',
-        to   => $to   // '@HEAD',
+        from => $self->from // '@ROOT',
+        to   => $self->to   // '@HEAD',
     ));
 
-    $self->_mkpath( $dir );
-    $target->plan->write_to(
-        $dir->file( $target->plan_file->basename ),
-        $from,
-        $to,
+    $sqitch->plan->write_to(
+        $self->dest_top_dir->file( $sqitch->plan_file->basename ),
+        $self->from,
+        $self->to,
     );
 }
 
 sub bundle_scripts {
-    my ($self, $target, $from, $to) = @_;
-    my $plan = $target->plan;
+    my $self = shift;
+    my $top  = $self->sqitch->top_dir;
+    my $plan = $self->plan;
+    my $dir  = $self->dest_dir;
 
     my $from_index = $plan->index_of(
-        $from // '@ROOT'
+        $self->from // '@ROOT'
     ) // hurl bundle => __x(
         'Cannot find change {change}',
-        change => $from,
+        change => $self->from,
     );
 
     my $to_index = $plan->index_of(
-        $to // '@HEAD'
+        $self->to // '@HEAD'
     ) // hurl bundle => __x(
         'Cannot find change {change}',
-        change => $to,
+        change => $self->to,
     );
 
     $self->info(__ 'Writing scripts');
     $plan->position( $from_index );
-    my $dir_for = $self->dest_dirs_for($target);
-
     while ( $plan->position <= $to_index ) {
         my $change = $plan->current // last;
         $self->info('  + ', $change->format_name_with_tags);
-        my $prefix = $change->is_reworked ? 'reworked_' : '';
-        my @path = $change->path_segments;
         if (-e ( my $file = $change->deploy_file )) {
             $self->_copy_if_modified(
                 $file,
-                $dir_for->{"${prefix}deploy"}->file(@path)
+                $self->dest_deploy_dir->file( $file->basename )
             );
         }
         if (-e ( my $file = $change->revert_file )) {
             $self->_copy_if_modified(
                 $file,
-                $dir_for->{"${prefix}revert"}->file(@path)
+                $self->dest_revert_dir->file( $file->basename )
             );
         }
-        if (-e ( my $file = $change->verify_file )) {
+        if (-e ( my $file = $change->test_file )) {
             $self->_copy_if_modified(
                 $file,
-                $dir_for->{"${prefix}verify"}->file(@path)
+                $self->dest_test_dir->file( $file->basename )
             );
         }
         $plan->next;
@@ -267,21 +258,6 @@ and copying the configuration file, plan file, and change files into it.
 
 =head1 Interface
 
-=head2 Attributes
-
-=head3 C<from>
-
-Change from which to build the bundled plan.
-
-=head3 C<to>
-
-Change up to which to build the bundled plan.
-
-=head3 C<all>
-
-Boolean indicating whether or not to run the command against all plans in the
-project.
-
 =head2 Instance Methods
 
 =head3 C<execute>
@@ -298,46 +274,17 @@ Copies the configuration file to the bundle directory.
 
 =head3 C<bundle_plan>
 
- $bundle->bundle_plan($target);
+ $bundle->bundle_plan;
 
-Copies the plan file for the specified target to the bundle directory.
+Copies the plan file to the bundle directory.
 
 =head3 C<bundle_scripts>
 
- $bundle->bundle_scripts($target);
+ $bundle->bundle_scripts;
 
-Copies the deploy, revert, and verify scripts for each step in the plan for
-the specified target to the bundle directory. Files in the script directories
-that do not correspond to changes in the plan will not be copied.
-
-=head3 C<dest_top_dir>
-
-  my $top_dir = $bundle->top_dir($target);
-
-Returns the destination top directory for the specified target.
-
-=head3 C<dest_dirs_for>
-
-  my $dirs = $bundle->dest__dirs_for($target);
-
-Returns a hash of change script destination directories for the specified
-target. The keys are the types of scripts, and include:
-
-=over
-
-=item C<deploy>
-
-=item C<revert>
-
-=item C<verfiy>
-
-=item C<reworked_deploy>
-
-=item C<reworked_revert>
-
-=item C<reworked_verfiy>
-
-=back
+Copies the deploy, revert, and test scripts for each step in the plan to the
+bundle directory. Files in the script directories that do not correspond to
+changes in the plan will not be copied.
 
 =head1 See Also
 
@@ -359,7 +306,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
