@@ -1,6 +1,6 @@
 package App::Sqitch::Command::config;
 
-use 5.010;
+use v5.10.1;
 use strict;
 use warnings;
 use utf8;
@@ -9,13 +9,12 @@ use Try::Tiny;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
 use List::Util qw(first);
-use Moo;
-use App::Sqitch::Types qw(Str Dir Maybe);
-use Type::Utils qw(enum);
+use Moose;
+use Moose::Util::TypeConstraints;
 use namespace::autoclean;
 extends 'App::Sqitch::Command';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
 has file => (
     is      => 'ro',
@@ -31,27 +30,27 @@ has action => (
     is  => 'ro',
     isa => enum([qw(
         get
-        get_all
-        get_regex
+        get-all
+        get-regex
         set
         unset
         list
         edit
         add
-        replace_all
-        unset_all
-        rename_section
-        remove_section
+        replace-all
+        unset-all
+        rename-section
+        remove-section
     )]),
 );
 
 has context => (
     is  => 'ro',
-    isa => Maybe[enum([qw(
+    isa => maybe_type enum([qw(
         local
         user
         system
-    )])],
+    )]),
 );
 
 has type => ( is => 'ro', isa => enum( [qw(int num bool bool-or-int)] ) );
@@ -60,7 +59,7 @@ sub options {
     return qw(
         file|config-file|f=s
         local
-        user|global
+        user
         system
 
         int
@@ -70,7 +69,7 @@ sub options {
 
         get
         get-all
-        get-regex|get-regexp
+        get-regex
         add
         replace-all
         unset
@@ -90,22 +89,22 @@ sub configure {
     $class->usage('Only one config file at a time.') if @file > 1;
 
     # Make sure we have only one type.
-    my @type = grep { $opt->{$_} } qw(bool int num bool_or_int);
+    my @type = grep { $opt->{$_} } qw(bool int num bool-or-int);
     $class->usage('Only one type at a time.') if @type > 1;
 
     # Make sure we are performing only one action.
     my @action = grep { $opt->{$_} } qw(
         get
-        get_all
-        get_regex
+        get-all
+        get-regex
         unset
         list
         edit
         add
-        replace_all
+        replace-all
         unset_all
-        rename_section
-        remove_section
+        rename-section
+        remove-section
     );
     $class->usage('Only one action at a time.') if @action > 1;
 
@@ -181,7 +180,7 @@ sub get_all {
         message => '',
         exitval => 1,
     } unless @vals;
-    $self->emit( join "\n", @vals );
+    $self->emit( join $/, @vals );
     return $self;
 }
 
@@ -220,7 +219,7 @@ sub get_regex {
             push @out => $key;
         }
     }
-    $self->emit( join "\n" => @out );
+    $self->emit( join $/ => @out );
 
     return $self;
 }
@@ -322,9 +321,7 @@ sub edit {
     my $self = shift;
 
     # Let the editor deal with locking.
-    $self->shell(
-        $self->sqitch->editor . ' ' . $self->quote_shell( $self->file )
-    );
+    $self->run( $self->sqitch->editor, $self->file );
 }
 
 sub rename_section {
@@ -376,7 +373,8 @@ sub _touch_dir {
     }
 }
 
-1;
+__PACKAGE__->meta->make_immutable;
+no Moose;
 
 __END__
 
@@ -445,7 +443,7 @@ The action to be executed. May be one of:
 
 =item * C<get-all>
 
-=item * C<get-regexp>
+=item * C<get-regex>
 
 =item * C<set>
 
@@ -642,7 +640,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
