@@ -1,38 +1,22 @@
 package App::Sqitch::Command::help;
 
-use 5.010;
+use v5.10.1;
 use strict;
 use warnings;
 use utf8;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use Types::Standard qw(Bool);
 use Pod::Find;
-use Moo;
+use Moose;
 extends 'App::Sqitch::Command';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
-has guide => (
-    is      => 'ro',
-    isa     => Bool,
-    default => 0,
-);
-
-sub options {
-    # XXX Add --all at some point, to output a list of all possible commands.
-    return qw(
-        guide|g
-    );
-}
+# XXX Add --all at some point, to output a list of all possible commands.
 
 sub execute {
     my ( $self, $command ) = @_;
-    $self->find_and_show('sqitch' . (
-          $command     ? ($command =~ /^changes|tutorial/ ? '' : '-') . $command
-        : $self->guide ? 'guides'
-                       : 'commands'
-    ));
+    $self->find_and_show('sqitch' . ( $command ? "-$command" : 'commands' ));
 }
 
 sub find_and_show {
@@ -76,12 +60,6 @@ works, read on.
 
 =head1 Interface
 
-=head2 Attributes
-
-=head3 C<guide>
-
-Boolean indicating whether to list the guides.
-
 =head2 Instance Methods
 
 =head3 C<execute>
@@ -90,7 +68,7 @@ Boolean indicating whether to list the guides.
 
 Executes the help command. If a command is passed, the help for that command will
 be shown. If it cannot be found, Sqitch will throw an error and exit. If no
-command is specified, the L<Sqitch core documentation|sqitch> will be shown.
+command is specified, the the L<Sqitch core documentation|sqitch> will be shown.
 
 =head3 C<find_and_show>
 
@@ -119,7 +97,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
