@@ -1,37 +1,24 @@
 package App::Sqitch::Command::status;
 
-use 5.010;
+use v5.10.1;
 use strict;
 use warnings;
 use utf8;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use Moo;
-use App::Sqitch::Types qw(Str Bool Target);
+use Moose;
+use Moose::Util::TypeConstraints;
+use App::Sqitch::DateTime;
 use List::Util qw(max);
 use Try::Tiny;
 use namespace::autoclean;
-
 extends 'App::Sqitch::Command';
-with 'App::Sqitch::Role::ContextCommand';
-with 'App::Sqitch::Role::ConnectingCommand';
 
-our $VERSION = 'v1.6.1'; # VERSION
-
-has target_name => (
-    is  => 'ro',
-    isa => Str,
-);
-
-has target => (
-    is      => 'rw',
-    isa     => Target,
-    handles => [qw(engine plan plan_file)],
-);
+our $VERSION = '9.93';
 
 has show_changes => (
     is      => 'ro',
-    isa     => Bool,
+    isa     => 'Bool',
     lazy    => 1,
     default => sub {
         shift->sqitch->config->get(
@@ -43,7 +30,7 @@ has show_changes => (
 
 has show_tags => (
     is      => 'ro',
-    isa     => Bool,
+    isa     => 'Bool',
     lazy    => 1,
     default => sub {
         shift->sqitch->config->get(
@@ -56,7 +43,7 @@ has show_tags => (
 has date_format => (
     is      => 'ro',
     lazy    => 1,
-    isa     => Str,
+    isa     => 'Str',
     default => sub {
         shift->sqitch->config->get( key => 'status.date_format' ) || 'iso'
     }
@@ -64,15 +51,12 @@ has date_format => (
 
 has project => (
     is      => 'ro',
-    isa     => Str,
+    isa     => 'Str',
     lazy    => 1,
     default => sub {
         my $self = shift;
-        try { $self->plan->project } catch {
-            # Just die on parse and I/O errors.
-            die $_ if try { $_->ident eq 'parse' || $_->ident eq 'io' };
-
-            # Try to extract a project name from the registry.
+        try { $self->plan->project } || do {
+            # Try to extract a project name from the database.
             my $engine = $self->engine;
             hurl status => __ 'Database not initialized for Sqitch'
                 unless $engine->initialized;
@@ -82,7 +66,7 @@ has project => (
                 'Use --project to select which project to query: {projects}',
                 projects => join __ ', ', @projs,
             ) if @projs > 1;
-            return $projs[0];
+            $projs[0];
         };
     },
 );
@@ -90,7 +74,6 @@ has project => (
 sub options {
     return qw(
         project=s
-        target|t=s
         show-tags
         show-changes
         date-format|date=s
@@ -98,66 +81,40 @@ sub options {
 }
 
 sub execute {
-    my $self = shift;
-    my ($targets) = $self->parse_args(
-        target => $self->target_name,
-        args   => \@_,
-    );
-
-    # Warn on multiple targets.
-    my $target = shift @{ $targets };
-    $self->warn(__x(
-        'Too many targets specified; connecting to {target}',
-        target => $target->name,
-    )) if @{ $targets };
-
-    # Good to go.
-    $self->target($target);
-    my $engine = $target->engine;
+    my $self   = shift;
+    my $engine = $self->engine;
 
     # Where are we?
     $self->comment( __x 'On database {db}', db => $engine->destination );
 
     # Exit with status 1 on no state, probably not expected.
-    my $state = try {
-        $engine->current_state( $self->project )
-    } catch {
-        # Just die on parse and I/O errors.
-        die $_ if try { $_->ident eq 'parse' || $_->ident eq 'io' };
-
-        # Hrm. Maybe not initialized?
-        die $_ if $engine->initialized;
-        hurl status => __x(
-            'Database {db} has not been initialized for Sqitch',
-            db => $engine->registry_destination
-        );
-    };
-
-    hurl {
+    my $state = $engine->current_state( $self->project ) || hurl {
         ident   => 'status',
         message => __ 'No changes deployed',
         exitval => 1,
-    } unless $state;
+    };
 
     # Emit the state basics.
     $self->emit_state($state);
 
-    # Emit changes and tags, if required.
-    $self->emit_changes;
-    $self->emit_tags;
-
-    my $plan_proj = try { $target->plan->project };
-    if (defined $plan_proj && $self->project eq $plan_proj ) {
-        $self->emit_status($state);
-    } else {
-        # If we have no access to the project plan, we can't emit the status.
+    # If we have no access to the project plan, we can't emit the status.
+    my $plan_proj = try { $self->plan->project };
+    if ( !defined $plan_proj || $self->project ne $plan_proj ) {
         $self->comment('');
         $self->emit(__x(
             'Status unknown. Use --plan-file to assess "{project}" status',
             project => $self->project,
         ));
+        return $self;
     }
 
+    # Emit changes and tags, if required.
+    $self->emit_changes;
+    $self->emit_tags;
+
+    # Emit the overall status.
+    $self->emit_status($state);
+
     return $self;
 }
 
@@ -165,23 +122,13 @@ sub configure {
     my ( $class, $config, $opt ) = @_;
 
     # Make sure the date format is valid.
-    if (my $format = $opt->{date_format}
+    if (my $format = $opt->{'date-format'}
         || $config->get(key => 'status.date_format')
     ) {
-        require App::Sqitch::DateTime;
         App::Sqitch::DateTime->validate_as_string_format($format);
     }
 
-    # Set boolean options from config.
-    for my $key (qw(show_changes show_tags)) {
-        next if exists $opt->{$key};
-        my $val = $config->get(key => "status.$key", as => 'bool') // next;
-        $opt->{$key} = $val;
-    }
-
-    my $ret = $class->SUPER::configure( $config, $opt );
-    $ret->{target_name} = delete $ret->{target} if exists $ret->{target};
-    return $ret;
+    return $class->SUPER::configure( $config, $opt );
 }
 
 sub emit_state {
@@ -297,7 +244,7 @@ sub emit_status {
     my $idx = $plan->index_of( $state->{change_id} ) // do {
         $self->vent(__x(
             'Cannot find this change in {file}',
-            file => $self->plan_file
+            file => $self->sqitch->plan_file
         ));
         hurl status => __ 'Make sure you are connected to the proper '
                         . 'database for this project.';
@@ -341,25 +288,14 @@ works, read on.
 
 =head1 Interface
 
-=head2 Attributes
-
-=head3 C<target_name>
-
-The name or URI of the database target as specified by the C<--target> option.
-
-=head3 C<target>
-
-An L<App::Sqitch::Target> object from which to read the status. Must be
-instantiated by C<execute()>.
-
 =head2 Instance Methods
 
 =head3 C<execute>
 
   $status->execute;
 
-Executes the status command. The current state of the target database will be
-compared to the plan in order to show where things stand.
+Executes the status command. The current state of the database will be compared
+to the plan in order to show where things stand.
 
 =head3 C<emit_changes>
 
@@ -377,15 +313,15 @@ Emits a list of deployed tags if C<show_tags> is true.
 
   $status->emit_state($state);
 
-Emits the current state of the target database. Pass in a state hash as
-returned by L<App::Sqitch::Engine> C<current_state()>.
+Emits the current state of the database. Pass in a state hash as returned by
+L<App::Sqitch::Engine> C<current_state()>.
 
 =head3 C<emit_status>
 
   $status->emit_state($state);
 
-Emits information about the current status of the target database compared to
-the plan. Pass in a state hash as returned by L<App::Sqitch::Engine>
+Emits information about the current status of the database compared to the
+plan. Pass in a state hash as returned by L<App::Sqitch::Engine>
 C<current_state()>. Throws an exception if the current state's change cannot
 be found in the plan.
 
@@ -409,7 +345,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
