@@ -1,32 +1,29 @@
 package App::Sqitch::Config;
 
-use 5.010;
-use Moo;
+use v5.10.1;
+use Moose;
 use strict;
 use warnings;
 use Path::Class;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use Config::GitLike 1.15;
+use Config::GitLike 1.09;
 use utf8;
 
 extends 'Config::GitLike';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
 has '+confname' => ( default => 'sqitch.conf' );
 has '+encoding' => ( default => 'UTF-8' );
 
-# Set by ./Build; see Module::Build::Sqitch for details.
 my $SYSTEM_DIR = undef;
 
-sub home_dir {
-    $^O eq 'MSWin32' && "$]" < '5.016' ? $ENV{HOME} || $ENV{USERPROFILE} : (glob('~'))[0]
-}
-
 sub user_dir {
-    my $hd = home_dir;
-    hurl config => __("Could not determine home directory") if not $hd;
+    require File::HomeDir;
+    my $hd = File::HomeDir->my_home or hurl config => __(
+        "Could not determine home directory"
+    );
     return dir $hd, '.sqitch';
 }
 
@@ -58,53 +55,19 @@ sub local_file {
 
 sub dir_file { shift->local_file }
 
-# Section keys always have the top section lowercase, and subsections are
-# left as-is.
-sub _skey($) {
-    my $key = shift // return '';
-    my ($sec, $sub, $name) = Config::GitLike::_split_key($key);
-    return lc $key unless $sec;
-    return lc($sec) . '.' . join '.',   grep { defined } $sub, $name;
-}
-
 sub get_section {
     my ( $self, %p ) = @_;
     $self->load unless $self->is_loaded;
-    my $section = _skey $p{section};
+    my $section = $p{section} // '';
     my $data    = $self->data;
     return {
-        map  {
-            ( split /[.]/ => $self->initial_key("$section.$_") )[-1],
-            $data->{"$section.$_"}
-        }
+        map { $_ => $data->{"$section.$_"} }
         grep { s{^\Q$section.\E([^.]+)$}{$1} } keys %{$data}
     };
 }
 
-sub initial_key {
-    my $key = shift->original_key(shift);
-    return ref $key ? $key->[0] : $key;
-}
-
-sub initialized {
-    my $self = shift;
-    $self->load unless $self->is_loaded;
-    return $self->{_initialized};
-}
-
-sub load_dirs {
-    my $self = shift;
-    local $self->{__loading_dirs} = 1;
-    $self->SUPER::load_dirs(@_);
-}
-
-sub load_file {
-    my $self = shift;
-    $self->{_initialized} ||= $self->{__loading_dirs};
-    $self->SUPER::load_file(@_);
-}
-
-1;
+__PACKAGE__->meta->make_immutable;
+no Moose;
 
 =head1 Name
 
@@ -123,36 +86,26 @@ module.
 
 =head1 Interface
 
-=head2 Class Methods
-
-=head3 C<home_dir>
-
-  my $hd = App::Sqitch->home_dir;
-
-Returns the likely path to the user's hone directory.
-
-=head3 C<user_dir>
-
-Returns the path to the user configuration directory, which is F<~/.sqitch/>.
-
-=head3 C<system_dir>
-
-Returns the path to the system configuration directory, which is
-F<$(prefix)/etc/sqitch/templates>. Call C<sqitch --etc-path> to find out
-where, exactly (e.g., C<$(sqitch --etc-path)/sqitch.plan>).
-
 =head2 Instance Methods
 
 =head3 C<confname>
 
 Returns the configuration file base name, which is F<sqitch.conf>.
 
+=head3 C<system_dir>
+
+Returns the path to the system configuration directory, which is
+C<$Config{prefix}/etc/sqitch/>.
+
+=head3 C<user_dir>
+
+Returns the path to the user configuration directory, which is F<~/.sqitch/>.
+
 =head3 C<system_file>
 
 Returns the path to the system configuration file. The value returned will be
 the contents of the C<$SQITCH_SYSTEM_CONFIG> environment variable, if it's
-defined, or else F<$(prefix)/etc/sqitch/templates>. Call C<sqitch --etc-path>
-to find out where, exactly (e.g., C<$(sqitch --etc-path)/sqitch.plan>).
+defined, or else C<$Config{prefix}/etc/sqitch/sqitch.conf>.
 
 =head3 C<global_file>
 
@@ -174,18 +127,10 @@ will be returned.
 
 An alias for C<local_file()> for use by the parent class.
 
-=head3 C<initialized>
-
-  say 'Project not initialized' unless $config->initialized;
-
-Returns true if the project configuration file was found, and false if it was
-not. Useful for detecting when a command has been run from a directory with no
-Sqitch configuration.
-
 =head3 C<get_section>
 
   my $core = $config->get_section(section => 'core');
-  my $pg   = $config->get_section(section => 'engine.pg');
+  my $pg   = $config->get_section(section => 'core.pg');
 
 Returns a hash reference containing only the keys within the specified
 section or subsection.
@@ -194,14 +139,6 @@ section or subsection.
 
 Adds a comment to the configuration file.
 
-=head3 C<initial_key>
-
-  my $key = $config->initial_key($data_key);
-
-Given the lowercase key from the loaded data, this method returns it in its
-original case. This is like C<original_key>, only in the case where there are
-multiple keys (for multivalue keys), only the first key is returned.
-
 =head1 See Also
 
 =over
@@ -220,7 +157,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -241,3 +178,4 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 
 =cut
+
