@@ -1,17 +1,14 @@
 package App::Sqitch::DateTime;
 
-use 5.010;
+use v5.10.1;
 use strict;
 use warnings;
 use utf8;
 use parent 'DateTime';
-use DateTime 1.04;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use List::Util qw(first);
-use constant ISWIN => $^O eq 'MSWin32';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
 sub as_string_formats {
     return qw(
@@ -32,7 +29,7 @@ sub validate_as_string_format {
     hurl datetime => __x(
         'Unknown date format "{format}"',
         format => $format
-    ) unless (first { $format eq $_ } $self->as_string_formats)
+    ) unless $format ~~ [ $self->as_string_formats ]
           || $format =~ /^(?:cldr|strftime):/;
     return $self;
 }
@@ -49,20 +46,20 @@ sub as_string {
 
     $dt->set_time_zone('local');
 
-    if ( first { $format eq $_ } qw(iso iso8601) ) {
+    if ( $format ~~ [qw(iso iso8601)] ) {
         return join ' ', $dt->ymd('-'), $dt->hms(':'), $dt->strftime('%z');
-    } elsif ( first { $format eq $_ } qw(rfc rfc2822) ) {
-        $dt->set_locale('en_US');
+    } elsif ( $format ~~ [qw(rfc rfc2822)] ) {
+        $dt->set( locale => 'en_US' );
         ( my $rv = $dt->strftime('%a, %d %b %Y %H:%M:%S %z') ) =~
             s/\+0000$/-0000/;
         return $rv;
     } else {
-        if (ISWIN) {
+        if ($^O eq 'Win32') {
             require Win32::Locale;
-            $dt->set_locale( Win32::Locale::get_locale() );
+            $dt->set( locale => Win32::Locale::get_locale() );
         } else {
             require POSIX;
-            $dt->set_locale( POSIX::setlocale( POSIX::LC_TIME() ) );
+            $dt->set( locale => POSIX::setlocale( POSIX::LC_TIME() ) );
         }
         return $dt->format_cldr($format) if $format =~ s/^cldr://;
         return $dt->strftime($format) if $format =~ s/^strftime://;
@@ -191,7 +188,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
