@@ -1,7 +1,8 @@
 package App::Sqitch::Plan;
 
-use 5.010;
+use v5.10.1;
 use utf8;
+use App::Sqitch::DateTime;
 use App::Sqitch::Plan::Tag;
 use App::Sqitch::Plan::Change;
 use App::Sqitch::Plan::Blank;
@@ -12,13 +13,11 @@ use App::Sqitch::Plan::ChangeList;
 use App::Sqitch::Plan::LineList;
 use Locale::TextDomain qw(App-Sqitch);
 use App::Sqitch::X qw(hurl);
-use List::MoreUtils qw(uniq any);
 use namespace::autoclean;
-use Moo;
-use App::Sqitch::Types qw(Str Int HashRef ChangeList LineList Maybe Sqitch URI File Target);
-use constant SYNTAX_VERSION => '1.0.0';
+use Moose;
+use constant SYNTAX_VERSION => '1.0.0-b2';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
 # Like [:punct:], but excluding _. Copied from perlrecharclass.
 my $punct = q{-!"#$%&'()*+,./:;<=>?@[\\]^`{|}~};
@@ -26,47 +25,29 @@ my $name_re = qr{
     (?![$punct])                   # first character isn't punctuation
     (?:                            # start non-capturing group, repeated once or more ...
        (?!                         #     negative look ahead for...
-           [~/=%^\[\]]             #         symbolic reference punctuation
+           [~/=%^]                 #         symbolic reference punctuation
            [[:digit:]]+            #         digits
            (?:$|[[:blank:]])       #         eol or blank
        )                           #     ...
-       [^[:blank:]:@#\\]           #     match a valid character
+       [^[:blank:]:@#]             #     match a valid character
     )+                             # ... end non-capturing group
     (?<![$punct])\b                # last character isn't punctuation
 }x;
 
-my $dir_sep_re = qr{/};
-
-my %reserved = map { $_ => undef } qw(ROOT HEAD);
+my %reserved = map { $_ => undef } qw(ROOT HEAD FIRST LAST);
 
 sub name_regex { $name_re }
 
 has sqitch => (
     is       => 'ro',
-    isa      => Sqitch,
+    isa      => 'App::Sqitch',
     required => 1,
     weak_ref => 1,
 );
 
-has target => (
-    is       => 'ro',
-    isa      => Target,
-    required => 1,
-    weak_ref => 1,
-);
-
-has file => (
-    is      => 'ro',
-    isa     => File,
-    lazy    => 1,
-    default => sub {
-        shift->target->plan_file
-    },
-);
-
 has _plan => (
-    is         => 'rw',
-    isa        => HashRef,
+    is         => 'ro',
+    isa        => 'HashRef',
     builder    => 'load',
     init_arg   => 'plan',
     lazy       => 1,
@@ -75,8 +56,9 @@ has _plan => (
 
 has _changes => (
     is       => 'ro',
-    isa      => ChangeList,
+    isa      => 'App::Sqitch::Plan::ChangeList',
     lazy     => 1,
+    required => 1,
     default  => sub {
         App::Sqitch::Plan::ChangeList->new(@{ shift->_plan->{changes} }),
     },
@@ -84,8 +66,9 @@ has _changes => (
 
 has _lines => (
     is       => 'ro',
-    isa      => LineList,
+    isa      => 'App::Sqitch::Plan::LineList',
     lazy     => 1,
+    required => 1,
     default  => sub {
         App::Sqitch::Plan::LineList->new(@{ shift->_plan->{lines} }),
     },
@@ -93,13 +76,15 @@ has _lines => (
 
 has position => (
     is       => 'rw',
-    isa      => Int,
+    isa      => 'Int',
+    required => 1,
     default  => -1,
 );
 
 has project => (
     is       => 'ro',
-    isa      => Str,
+    isa      => 'Str',
+    required => 1,
     lazy     => 1,
     default  => sub {
         shift->_plan->{pragmas}{project};
@@ -108,37 +93,28 @@ has project => (
 
 has uri => (
     is       => 'ro',
-    isa      => Maybe[URI],
+    isa      => 'Maybe[URI]',
+    required => 0,
     lazy     => 1,
     default  => sub {
         my $uri = shift->_plan->{pragmas}{uri} || return;
         require URI;
-        'URI'->new($uri);
+        URI->new($uri);
     }
 );
 
-sub parse {
-    my ( $self, $data ) = @_;
-    open my $fh, '<:utf8_strict', \$data;
-    $self->_plan( $self->load($fh) );
-    return $self;
-}
-
 sub load {
     my $self = shift;
-    my $file = $self->file;
-    my $fh = shift || do {
-        hurl plan => __x('Plan file {file} does not exist', file => $file)
-            unless -e $file;
-        hurl plan => __x('Plan file {file} is not a regular file', file => $file)
-            unless -f $file;
-        $file->open('<:utf8_strict') or hurl io => __x(
-            'Cannot open {file}: {error}',
-            file  => $file,
-            error => $!
-        );
-    };
-
+    my $file = $self->sqitch->plan_file;
+    hurl plan => __x('Plan file {file} does not exist', file => $file)
+        unless -e $file;
+    hurl plan => __x('Plan file {file} is not a regular file', file => $file)
+        unless -f $file;
+    my $fh = $file->open('<:encoding(UTF-8)') or hurl plan => __x(
+        'Cannot open {file}: {error}',
+        file  => $file,
+        error => $!
+    );
     return $self->_parse($file, $fh);
 }
 
@@ -180,7 +156,7 @@ sub _parse {
 
     # Use for raising syntax error exceptions.
     my $raise_syntax_error = sub {
-        hurl parse => __x(
+        hurl plan => __x(
             'Syntax error in {file} at line {lineno}: {error}',
             file   => $file,
             lineno => $fh->input_line_number,
@@ -190,7 +166,7 @@ sub _parse {
 
     # First, find pragmas.
     HEADER: while ( my $line = $fh->getline ) {
-        $line =~ s/\r?\n\z//;
+        chomp $line;
 
         # Grab blank lines first.
         if ($line =~ /\A(?<lspace>[[:blank:]]*)(?:#[[:blank:]]*(?<note>.+)|$)/) {
@@ -237,8 +213,8 @@ sub _parse {
             my $proj = $+{value};
             $raise_syntax_error->(__x(
                 qq{invalid project name "{project}": project names must not }
-                . 'begin with punctuation, contain "@", ":", "#", "\\", "[", "]", or blanks, '
-                . 'or end in punctuation or digits following punctuation',
+                . 'begin with punctuation, contain "@", ":", or "#", or end in '
+                . 'punctuation or digits following punctuation',
                 project => $proj,
             )) unless $proj =~ /\A$name_re\z/;
             $pragmas{project} = $proj;
@@ -261,13 +237,13 @@ sub _parse {
     }
 
     # Should have valid project pragma.
-    hurl parse => __x(
+    hurl plan => __x(
         'Missing %project pragma in {file}',
         file => $file,
     ) unless $pragmas{project};
 
     LINE: while ( my $line = $fh->getline ) {
-        $line =~ s/\r?\n\z//;
+        chomp $line;
 
         # Grab blank lines first.
         if ($line =~ /\A(?<lspace>[[:blank:]]*)(?:#[[:blank:]]*(?<note>.+)|$)/) {
@@ -318,7 +294,7 @@ sub _parse {
         # Raise errors for missing data.
         $raise_syntax_error->(__(
             qq{Invalid name; names must not begin with punctuation, }
-            . 'contain "@", ":", "#", "\\", "[", "]", or blanks, or end in punctuation or digits following punctuation',
+            . 'contain "@", ":", or "#", or end in punctuation or digits following punctuation',
         )) if !$params{name}
             || (!$params{yr} && $line =~ $ts_re);
 
@@ -342,7 +318,6 @@ sub _parse {
         )) if $params{name} =~ /^[0-9a-f]{40}/;
 
         # Assemble the timestamp.
-        require App::Sqitch::DateTime;
         $params{timestamp} = App::Sqitch::DateTime->new(
             year      => delete $params{yr},
             month     => delete $params{mo},
@@ -354,15 +329,6 @@ sub _parse {
         );
 
         if ($type eq 'tag') {
-            # Faile if contains directory separators
-            if ($params{name} =~ qr/($dir_sep_re)/) {
-                $raise_syntax_error->(__x(
-                    'Tag "{tag}" contains illegal character {sep}',
-                    tag => $params{name},
-                    sep => $1,
-                ));
-            }
-
             # Fail if no changes.
             unless ($prev_change) {
                 $raise_syntax_error->(__x(
@@ -388,7 +354,7 @@ sub _parse {
 
             if (@curr_changes) {
                 # Sort all changes up to this tag by their dependencies.
-                push @changes => $self->check_changes(
+                push @changes => $self->sort_changes(
                     $pragmas{project},
                     \%line_no_for,
                     @curr_changes,
@@ -420,7 +386,7 @@ sub _parse {
 
             # Got dependencies?
             if (my $deps = $params{dependencies}) {
-                my (@req, @con, %seen_dep);
+                my (@req, @con);
                 for my $depstring (split /[[:blank:]]+/, $deps) {
                     my $dep_params = App::Sqitch::Plan::Depend->parse(
                         $depstring,
@@ -432,10 +398,6 @@ sub _parse {
                         plan => $self,
                         %{ $dep_params },
                     );
-                    # Prevent dupes.
-                    $raise_syntax_error->(
-                        __x( 'Duplicate dependency "{dep}"', dep => $depstring ),
-                    ) if $seen_dep{$depstring}++;
                     if ($dep->conflicts) {
                         push @con => $dep;
                     } else {
@@ -449,27 +411,21 @@ sub _parse {
             $tag_changes{ $params{name} } = $fh->input_line_number;
             push @curr_changes => $prev_change = App::Sqitch::Plan::Change->new(
                 plan => $self,
-                ( $prev_tag    ? ( since_tag => $prev_tag    ) : () ),
-                ( $prev_change ? ( parent    => $prev_change ) : () ),
+                ( $prev_tag ? ( since_tag => $prev_tag ) : () ),
                 %params,
             );
             push @lines => $prev_change;
 
             if (my $duped = $change_named{ $params{name} }) {
-                # Get rework tags by change in reverse order to reworked change.
-                my @rework_tags;
-                for (my $i = $#changes; $changes[$i] ne $duped; $i--) {
-                    push @rework_tags => $changes[$i]->tags;
-                }
-                # Add list of rework tags to the reworked change.
-                $duped->add_rework_tags(@rework_tags, $duped->tags);
+                # Mark previously-seen change of same name as duped.
+                $duped->suffix($prev_tag->format_name);
             }
             $change_named{ $params{name} } = $prev_change;
         }
     }
 
     # Sort and store any remaining changes.
-    push @changes => $self->check_changes(
+    push @changes => $self->sort_changes(
         $pragmas{project},
         \%line_no_for,
         @curr_changes,
@@ -491,16 +447,21 @@ sub _version_line {
     );
 }
 
-sub check_changes {
+sub sort_changes {
     my ( $self, $proj ) = ( shift, shift );
     my $seen = ref $_[0] eq 'HASH' ? shift : {};
 
-    my %position;
-    my @invalid;
-
-    my $i = 0;
+    my %obj;             # maps change names to objects.
+    my %pairs;           # all pairs ($l, $r)
+    my %npred;           # number of predecessors
+    my %succ;            # list of successors
     for my $change (@_) {
-        my @bad;
+
+        # Stolen from http://cpansearch.perl.org/src/CWEST/ppt-0.14/bin/tsort.
+        my $name = $change->name;
+        $obj{$name} = $change;
+        my $p = $pairs{$name} = {};
+        $npred{$name} += 0;
 
         # XXX Ignoring conflicts for now.
         for my $dep ( $change->requires ) {
@@ -524,81 +485,52 @@ sub check_changes {
                     }
                 }
             } else {
-                # Skip it if we've already seen it in the plan.
-                next if exists $seen->{$key} || $position{$key};
+                next if exists $seen->{$key};
             }
 
-            # Hrm, unknown dependency.
-            push @bad, $key;
+            $p->{$key}++;
+            $npred{$key}++;
+            push @{ $succ{$name} } => $key;
         }
-        $position{$change->name} = ++$i;
-        push @invalid, [ $change->name => \@bad ] if @bad;
     }
 
+    # Stolen from http://cpansearch.perl.org/src/CWEST/ppt-0.14/bin/tsort.
+    # Create a list of changes without predecessors
+    my @list = grep { !$npred{$_->name} } @_;
 
-    # Nothing bad, then go!
-    return @_ unless @invalid;
-
-    # Build up all of the error messages.
-    my @errors;
-    for my $bad (@invalid) {
-        my $change = $bad->[0];
-        my $max_delta = 0;
-        for my $dep (@{ $bad->[1] }) {
-            if ($change eq $dep) {
-                push @errors => __x(
-                    'Change "{change}" cannot require itself',
-                    change => $change,
-                );
-            } elsif (my $pos = $position{ $dep }) {
-                my $delta = $pos - $position{$change};
-                $max_delta = $delta if $delta > $max_delta;
-                push @errors => __xn(
-                    'Change "{change}" planned {num} change before required change "{required}"',
-                    'Change "{change}" planned {num} changes before required change "{required}"',
-                    $delta,
-                    change   => $change,
-                    required => $dep,
-                    num      => $delta,
-                );
-            } else {
-                push @errors => __x(
+    my @ret;
+    while (@list) {
+        my $change = pop @list;
+        unshift @ret => $change;
+        foreach my $child ( @{ $succ{$change->name} } ) {
+            unless ( $pairs{$child} ) {
+                my $sqitch = $self->sqitch;
+                my $name = $change->name;
+                hurl plan => __x(
                     'Unknown change "{required}" required by change "{change}"',
-                    required => $dep,
-                    change   => $change,
+                    required => $child,
+                    change   => $name,
                 );
             }
-        }
-        if ($max_delta) {
-            # Suggest that the change be moved.
-            # XXX Potentially offer to move it and rewrite the plan.
-            $errors[-1] .= "\n    " .  __xn(
-                'HINT: move "{change}" down {num} line in {plan}',
-                'HINT: move "{change}" down {num} lines in {plan}',
-                $max_delta,
-                change => $change,
-                num    => $max_delta,
-                plan   => $self->file,
-            );
+            push @list, $obj{$child} unless --$npred{$child};
         }
     }
 
-    # Throw the exception with all of the errors.
-    hurl parse => join(
-        "\n  ",
-        __n(
-            'Dependency error detected:',
-            'Dependency errors detected:',
-            @errors
-        ),
-        @errors,
-    );
+    if ( my @cycles = map { $_->name } grep { $npred{$_->name} } @_ ) {
+        my $last = pop @cycles;
+        hurl plan => __x(
+            'Dependency cycle detected beween changes {changes}',
+            changes => join( __ ', ', map {
+                __x('"{quoted}"', quoted => $_)
+            } @cycles) . __ ' and ' . __x('"{quoted}"', quoted => $last)
+        );
+    }
+    return @ret;
 }
 
 sub open_script {
     my ( $self, $file ) = @_;
-    # return has higher precedence than or, so use ||.
-    return $file->open('<:utf8_strict') || hurl io => __x(
+    return $file->open('<:encoding(UTF-8)') or hurl plan => __x(
         'Cannot open {file}: {error}',
         file  => $file,
         error => $!,
@@ -612,74 +544,11 @@ sub tags           { shift->_changes->tags }
 sub count          { shift->_changes->count }
 sub index_of       { shift->_changes->index_of(shift) }
 sub get            { shift->_changes->get(shift) }
-sub contains       { shift->_changes->contains( shift ) }
 sub find           { shift->_changes->find(shift) }
 sub first_index_of { shift->_changes->first_index_of(@_) }
 sub change_at      { shift->_changes->change_at(shift) }
 sub last_tagged_change { shift->_changes->last_tagged_change }
 
-sub search_changes {
-    my ( $self, %p ) = @_;
-
-    my $reverse = 0;
-    if (my $d = delete $p{direction}) {
-        $reverse = $d =~ /^ASC/i  ? 0
-                 : $d =~ /^DESC/i ? 1
-                 : hurl 'Search direction must be either "ASC" or "DESC"';
-    }
-
-    # Limit with regular expressions?
-    my @filters;
-    if (my $regex = delete $p{planner}) {
-        $regex = qr/$regex/;
-        push @filters => sub { $_[0]->planner_name =~ $regex };
-    }
-    if (my $regex = delete $p{name}) {
-        $regex = qr/$regex/;
-        push @filters => sub { $_[0]->name =~ $regex };
-    }
-
-    # Match events?
-    if (my $op = lc(delete $p{operation} || '') ) {
-        push @filters => $op eq 'deploy' ? sub { $_[0]->is_deploy }
-                       : $op eq 'revert' ? sub { $_[0]->is_revert }
-                       : hurl qq{Unknown change operation "$op"};
-    }
-
-    my $changes = $self->_changes;
-    my $offset  = delete $p{offset} || 0;
-    my $limit   = delete $p{limit}  || 0;
-
-    hurl 'Invalid parameters passed to search_changes(): '
-        . join ', ', sort keys %p if %p;
-
-    # If no filters, we want to return everything.
-    push @filters => sub { 1 } unless @filters;
-
-    if ($reverse) {
-        # Go backwards.
-        my $index  = $changes->count - ($offset + 1);
-        my $end_at = $limit ? $index - $limit : -1;
-        return sub {
-            while ($index > $end_at) {
-                my $change = $changes->change_at($index--) or return;
-                return $change if any { $_->($change) } @filters;
-            }
-            return;
-        };
-    }
-
-    my $index  = $offset - 1;
-    my $end_at = $limit ? $index + $limit : $changes->count - 1;
-    return sub {
-        while ($index < $end_at) {
-            my $change = $changes->change_at(++$index) or return;
-            return $change if any { $_->($change) } @filters;
-        }
-        return;
-    };
-}
-
 sub seek {
     my ( $self, $key ) = @_;
     my $index = $self->index_of($key);
@@ -743,32 +612,22 @@ sub tag {
         tag => $key
     ) if defined $changes->index_of($key);
 
-    my $change;
-    if (my $spec = $p{change}) {
-        $change = $changes->get($spec) or hurl plan => __x(
-            'Unknown change: "{change}"',
-            change => $spec,
-        );
-    } else {
-        $change = $changes->last_change or hurl plan => __x(
-            'Cannot apply tag "{tag}" to a plan with no changes',
-            tag => $key
-        );
-    }
+    my $change = $changes->last_change or hurl plan => __x(
+        'Cannot apply tag "{tag}" to a plan with no changes',
+        tag => $key
+    );
 
     my $tag = App::Sqitch::Plan::Tag->new(
         %p,
         plan   => $self,
         name   => $name,
         change => $change,
+        rspace => $p{note} ? ' ' : '',
     );
 
     $change->add_tag($tag);
     $changes->index_tag( $changes->index_of( $change->id ), $tag );
-
-    # Add tag to line list, after the change and any preceding tags.
-    my $lines = $self->_lines;
-    $lines->insert_at( $tag, $lines->index_of($change) + $change->tags );
+    $self->_lines->append( $tag );
     return $tag;
 }
 
@@ -785,7 +644,7 @@ sub _parse_deps {
             plan      => $self,
             conflicts => 0,
         );
-    } uniq @{ $p->{requires} } ] if $p->{requires};
+    } @{ $p->{requires} } ] if $p->{requires};
 
     $p->{conflicts} = [ map {
         my $p = App::Sqitch::Plan::Depend->parse("!$_") // hurl plan => __x(
@@ -797,7 +656,7 @@ sub _parse_deps {
             plan      => $self,
             conflicts => 1,
         );
-    } uniq @{ $p->{conflicts} } ] if $p->{conflicts};
+    } @{ $p->{conflicts} } ] if $p->{conflicts};
 }
 
 sub add {
@@ -808,14 +667,15 @@ sub add {
     if ( defined( my $idx = $changes->index_of( $p{name} . '@HEAD' ) ) ) {
         my $tag_idx = $changes->index_of_last_tagged;
         hurl plan => __x(
-            qq{Change "{change}" already exists in plan {file}.\n}
+            qq{Change "{change}" already exists.\n}
             . 'Use "sqitch rework" to copy and rework it',
             change => $p{name},
-            file   => $self->file,
         );
     }
 
     $self->_parse_deps(\%p);
+
+    $p{rspace} //= ' ' if $p{note};
     my $change = App::Sqitch::Plan::Change->new( %p, plan => $self );
 
     # Make sure dependencies are valid.
@@ -841,10 +701,9 @@ sub rework {
     my ( $self, %p ) = @_;
     my $changes = $self->_changes;
     my $idx   = $changes->index_of( $p{name} . '@HEAD') // hurl plan => __x(
-        qq{Change "{change}" does not exist in {file}.\n}
+        qq{Change "{change}" does not exist.\n}
         . 'Use "sqitch add {change}" to add it to the plan',
         change => $p{name},
-        file   => $self->file,
     );
 
     my $tag_idx = $changes->index_of_last_tagged;
@@ -870,7 +729,7 @@ sub rework {
     $self->_check_dependencies( $new, 'rework' );
 
     # We good.
-    $orig->add_rework_tags($tag);
+    $orig->suffix( $tag->format_name );
     $changes->append( $new );
     $self->_lines->append( $new );
     return $new;
@@ -881,6 +740,8 @@ sub _check_dependencies {
     my $changes = $self->_changes;
     my $project = $self->project;
     for my $req ( $change->requires ) {
+        # use Test::More; diag $req->key_name;
+        # diag $req->project, ' ne ', $project;
         next if $req->project ne $project;
         $req = $req->key_name;
         next if defined $changes->index_of($req =~ /@/ ? $req : $req . '@HEAD');
@@ -913,20 +774,21 @@ sub _is_valid {
         name => $name,
     ) if $name =~ /^[0-9a-f]{40}/;
 
-    if ($type eq 'change' && $name !~ /\A$name_re\z/) {
-        hurl plan => __x(
-            qq{"{name}" is invalid: changes must not begin with punctuation, }
-            . 'contain "@", ":", "#", "\\", "[", "]", or blanks, or end in punctuation or digits following punctuation',
-            name => $name,
-        );
-    } elsif ($type eq 'tag' && ($name !~ /\A$name_re\z/ || $name =~ $dir_sep_re)) {
-        hurl plan => __x(
-            qq{"{name}" is invalid: tags must not begin with punctuation, }
-            . 'contain "@", ":", "#", "/", "\\", "[", "]", or blanks, or end in punctuation or digits following punctuation',
-            name => $name,
-        );
+    unless ($name =~ /\A$name_re\z/) {
+        if ($type eq 'change') {
+            hurl plan => __x(
+                qq{"{name}" is invalid: changes must not begin with punctuation, }
+                . 'contain "@", ":", or "#", or end in punctuation or digits following punctuation',
+                name => $name,
+            );
+        } else {
+            hurl plan => __x(
+                qq{"{name}" is invalid: tags must not begin with punctuation, }
+                . 'contain "@", ":", or "#", or end in punctuation or digits following punctuation',
+                name => $name,
+            );
+        }
     }
-    return 1;
 }
 
 sub write_to {
@@ -978,13 +840,13 @@ sub write_to {
         );
     }
 
-    my $fh = $file->open('>:utf8_strict') or hurl io => __x(
+    my $fh = $file->open('>:encoding(UTF-8)') or hurl plan => __x(
         'Cannot open {file}: {error}',
         file  => $file,
         error => $!
     );
     $fh->say($_->as_string) for @lines;
-    $fh->close or hurl io => __x(
+    $fh->close or hurl plan => __x(
         '"Error closing {file}: {error}',
         file => $file,
         error => $!,
@@ -992,7 +854,8 @@ sub write_to {
     return $self;
 }
 
-1;
+__PACKAGE__->meta->make_immutable;
+no Moose;
 
 __END__
 
@@ -1047,22 +910,10 @@ an L<App::Sqitch> object.
 
 =head3 C<sqitch>
 
-  my $sqitch = $plan->sqitch;
+  my $sqitch = $cmd->sqitch;
 
 Returns the L<App::Sqitch> object that instantiated the plan.
 
-=head3 C<target>
-
-  my $target = $plan->target
-
-Returns the L<App::Sqitch::Target> passed to the constructor.
-
-=head3 C<file>
-
-  my $file = $plan->file;
-
-The file name from which to read the plan.
-
 =head3 C<position>
 
 Returns the current position of the iterator. This is an integer that's used
@@ -1133,20 +984,13 @@ The named change as it was last seen in the list before the specified tag.
 
 =back
 
-=head3 C<contains>
-
-  say 'Yes!' if $plan->contains('6c2f28d125aff1deea615f8de774599acf39a7a1');
-
-Like C<index_of()>, but never throws an exception, and returns true if the
-plan contains the specified change, and false if it does not.
-
 =head3 C<get>
 
   my $change = $plan->get('6c2f28d125aff1deea615f8de774599acf39a7a1');
-  my $foo    = $plan->get('@foo');
-  my $bar    = $plan->get('bar');
-  my $bar1   = $plan->get('bar@alpha')
-  my $bar2   = $plan->get('bar@HEAD');
+  my $foo  = $plan->index_of('@foo');
+  my $bar  = $plan->index_of('bar');
+  my $bar1 = $plan->index_of('bar@alpha')
+  my $bar2 = $plan->index_of('bar@HEAD');
 
 Returns the change corresponding to the specified ID or name. The argument may
 be in any of the formats described for C<index_of()>.
@@ -1154,10 +998,10 @@ be in any of the formats described for C<index_of()>.
 =head3 C<find>
 
   my $change = $plan->find('6c2f28d125aff1deea615f8de774599acf39a7a1');
-  my $foo    = $plan->find('@foo');
-  my $bar    = $plan->find('bar');
-  my $bar1   = $plan->find('bar@alpha')
-  my $bar2   = $plan->find('bar@HEAD');
+  my $foo  = $plan->index_of('@foo');
+  my $bar  = $plan->index_of('bar');
+  my $bar1 = $plan->index_of('bar@alpha')
+  my $bar2 = $plan->index_of('bar@HEAD');
 
 Finds the change corresponding to the specified ID or name. The argument may be
 in any of the formats described for C<index_of()>. Unlike C<get()>, C<find()>
@@ -1171,7 +1015,7 @@ but will return the first instance.
 
 Returns the index of the first instance of the named change in the plan. If a
 second argument is passed, the index of the first instance of the change
-I<after> the index of the second argument will be returned. This is useful
+I<after> the the index of the second argument will be returned. This is useful
 for getting the index of a change as it was deployed after a particular tag, for
 example, to get the first index of the F<foo> change since the C<@beta> tag, do
 this:
@@ -1284,49 +1128,6 @@ passed to the code reference. Iteration terminates when the code reference
 returns false, so be sure to have it return a true value if you want it to
 iterate over every change.
 
-=head3 C<search_changes>
-
-  my $iter = $engine->search_changes( %params );
-  while (my $change = $iter->()) {
-      say '* $change->{event}ed $change->{change}";
-  }
-
-Searches the changes in the plan returns an iterator code reference with the
-results. If no parameters are provided, a list of all changes will be returned
-from the iterator in plan order. The supported parameters are:
-
-=over
-
-=item C<event>
-
-An array of the type of event to search for. Allowed values are "deploy" and
- "revert".
-
-=item C<name>
-
-Limit the results to changes with names matching the specified regular
-expression.
-
-=item C<planner>
-
-Limit the changes to those added by planners matching the specified regular
-expression.
-
-=item C<limit>
-
-Limit the number of changes to the specified number.
-
-=item C<offset>
-
-Skip the specified number of events.
-
-=item C<direction>
-
-Return the results in the specified order, which must be a value matching
-C</^(:?a|de)sc/i> for "ascending" or "descending".
-
-=back
-
 =head3 C<write_to>
 
   $plan->write_to($file);
@@ -1350,61 +1151,24 @@ script file must be encoded in UTF-8.
 
 Loads the plan data. Called internally, not meant to be called directly, as it
 parses the plan file and deploy scripts every time it's called. If you want
-the all of the changes, call C<changes()> instead. And if you want to load an
-alternate plan, use C<parse()>.
+the all of the changes, call C<changes()> instead.
 
-=head3 C<parse>
+=head3 C<sort_changes>
 
-  $plan->parse($plan_data);
+  @changes = $plan->sort_changes( $project, @changes );
+  @changes = $plan->sort_changes( $project, { '@foo' => 1 }, @changes );
 
-Load an alternate plan by passing the complete text of the plan. The text
-should be UTF-8 encoded. Useful for loading a plan from a different VCS
-branch, for example.
-
-=head3 C<check_changes>
-
-  @changes = $plan->check_changes( $project, @changes );
-  @changes = $plan->check_changes( $project, { '@foo' => 1 }, @changes );
-
-Checks a list of changes to validate their dependencies and returns them. If
-the second argument is a hash reference, its keys should be previously-seen
-change and tag names that can be assumed to be satisfied requirements for the
-succeeding changes.
+Sorts a list of changes in dependency order and returns them. If the second
+argument is a hash reference, its keys should be previously-seen change and
+tag names that can be assumed to be satisfied requirements for the succeeding
+changes.
 
 =head3 C<tag>
 
-  $plan->tag( name => 'whee' );
+  $plan->tag('whee');
 
-Tags a change in the plan. Exits with a fatal error if the tag already exists
-in the plan or if a change cannot be found to tag. The supported parameters
-are:
-
-=over
-
-=item C<name>
-
-The tag name to use. Required.
-
-=item C<change>
-
-The change to be tagged, specified as a supported change specification as
-described in L<sqitchchanges>. Defaults to the last change in the plan.
-
-=item C<note>
-
-A brief note about the tag.
-
-=item C<planner_name>
-
-The name of the user adding the tag to the plan. Defaults to the value of the
-C<user.name> configuration variable.
-
-=item C<planner_email>
-
-The email address of the user adding the tag to the plan. Defaults to the
-value of the C<user.email> configuration variable.
-
-=back
+Tags the most recent change in the plan. Exits with a fatal error if the tag
+already exists in the plan.
 
 =head3 C<add>
 
@@ -1461,9 +1225,8 @@ character or a leading C<+> are to be deployed.
 =item * A tag.
 
 A named deployment tag, generally corresponding to a release name. Begins with
-a C<@>, followed by one or more non-blanks characters, excluding "@", ":",
-"#", and blanks. The first and last characters must not be punctuation
-characters.
+a C<@>, followed by one or more non-whitespace characters, excluding "@", ":",
+and "#". The first and last characters must not be punctuation characters.
 
 =item * A note.
 
@@ -1607,7 +1370,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
