@@ -1,50 +1,43 @@
 package App::Sqitch::X;
 
-use 5.010;
+use v5.10.1;
 use utf8;
-use Moo;
-use Types::Standard qw(Str Int);
+use Moose;
 use Sub::Exporter::Util ();
-use Throwable 0.200009;
 use Sub::Exporter -setup => [qw(hurl)];
+use Role::HasMessage 0.005;
+use Role::Identifiable::HasIdent 0.005;
+use Role::Identifiable::HasTags 0.005;
 use overload '""' => 'as_string';
 
-our $VERSION = 'v1.6.1'; # VERSION
+our $VERSION = '9.93';
 
 has message => (
     is       => 'ro',
-    isa      => Str,
+    isa      => 'Str',
     required => 1,
 );
 
 has exitval => (
-    is      => 'ro',
-    isa     => Int,
-    default => 2,
+    is       => 'ro',
+    isa      => 'Int',
+    required => 1,
+    default  => 2,
 );
 
 with qw(
     Throwable
+    Role::HasMessage
+    Role::Identifiable::HasIdent
     StackTrace::Auto
 );
 
-has ident => (
-  is      => 'ro',
-  isa     => Str,
-  default => 'DEV'
-);
-
-has '+previous_exception' => (init_arg => 'previous_exception')
-    if Throwable->VERSION < 0.200007;
+has '+ident' => (default => 'DEV');
 
 sub hurl {
     @_ = (
         __PACKAGE__,
-        # Always pass $@, as Throwable is unreliable about getting it thanks
-        # to hash randomization. Its workaround in v0.200006:
-        # https://github.com/rjbs/throwable/commit/596dfbafed970a30324dc21539d4edf2cbda767a
-        previous_exception => $@,
-        ref $_[0]     ? %{ $_[0] }
+        ref $_[0]     ? $_[0]
             : @_ == 1 ? (message => $_[0])
             :           (ident => $_[0],  message => $_[1])
     );
@@ -53,22 +46,15 @@ sub hurl {
 
 sub as_string {
     my $self = shift;
-    join "\n", grep { $_ } (
+    join $/, grep { defined } (
         $self->message,
         $self->previous_exception,
         $self->stack_trace
     );
 }
 
-sub details_string {
-    my $self = shift;
-    join "\n", grep { $_ } (
-        $self->previous_exception,
-        $self->stack_trace
-    );
-}
-
-1;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
+no Moose;
 
 __END__
 
@@ -78,7 +64,17 @@ App::Sqitch::X - Sqitch Exception class
 
 =head1 Synopsis
 
+Throw:
+
   use Locale::TextDomain;
+  use App::Sqitch::X;
+  open my $fh, '>', 'foo.txt' or App::Sqitch::X->throw(
+      ident   => 'io',
+      message => __x 'Cannot open {file}: {err}", file => 'foo.txt', err => $!,
+  );
+
+Hurl:
+
   use App::Sqitch::X qw(hurl);
   open my $fh, '>', 'foo.txt' or hurl {
       ident   => 'io',
@@ -97,11 +93,40 @@ handled, showing the error message to the user.
 
 =head1 Interface
 
+=head2 Class Method
+
+=head3 C<throw()>
+
+  open my $fh, '>', 'foo.txt' or App::Sqitch::X->throw(
+      ident   => 'io',
+      message => __x 'Cannot open {file}: {err}", file => 'foo.txt', err => $!,
+  );
+
+Throws an exception. The supported parameters include:
+
+=over
+
+=item C<ident>
+
+A non-localized string identifying the type of exception.
+
+=item C<message>
+
+The exception message. Use L<Locale::TextDomain> to craft localized messages.
+
+=item C<exitval>
+
+Suggested exit value to use. Defaults to 2. This will be used if Sqitch
+handles an exception while a command is running.
+
+=back
+
 =head2 Function
 
 =head3 C<hurl>
 
-Throws an exception. Pass the parameters as a hash reference, like so:
+To save yourself some typing, you can import the C<hurl> keyword and pass the
+parameters as a hash reference, like so:
 
   use App::Sqitch::X qw(hurl);
   open my $fh, '>', 'foo.txt' or hurl {
@@ -125,25 +150,6 @@ In this case, the C<ident> will be C<DEV>, which you should not otherwise use.
 Sqitch will emit a more detailed error message, including a stack trace, when
 it sees C<DEV> exceptions.
 
-The supported parameters are:
-
-=over
-
-=item C<ident>
-
-A non-localized string identifying the type of exception.
-
-=item C<message>
-
-The exception message. Use L<Locale::TextDomain> to craft localized messages.
-
-=item C<exitval>
-
-Suggested exit value to use. Defaults to 2. This will be used if Sqitch
-handles an exception while a command is running.
-
-=back
-
 =head2 Methods
 
 =head3 C<as_string>
@@ -155,13 +161,6 @@ used for string overloading of the exception object, which means it is the
 output shown for uncaught exceptions. Its contents are the concatenation of
 the exception message, the previous exception (if any), and the stack trace.
 
-=head3 C<details_string>
-
-  my $errstr = $x->details;
-
-Returns the the stringified version of the previous exception (if any), and
-the stack trace.
-
 =head1 Handling Exceptions
 
 use L<Try::Tiny> to do exception handling, like so:
@@ -189,7 +188,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 License
 
-Copyright (c) 2012-2026 David E. Wheeler, 2012-2021 iovation Inc.
+Copyright (c) 2012 iovation Inc.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
